@@ -14,7 +14,6 @@
 #  limitations under the License.
 #############################################################################
 
-import cherrypy
 import hashlib
 import math
 import os
@@ -22,23 +21,23 @@ import pathlib
 import re
 import urllib
 
+import cherrypy
+
 from girder.api import access, filter_logging
-from girder.api.v1.item import Item as ItemResource
-from girder.api.describe import autoDescribeRoute, describeRoute, Description
+from girder.api.describe import Description, autoDescribeRoute, describeRoute
 from girder.api.rest import filtermodel, loadmodel, setRawResponse, setResponseHeader
+from girder.api.v1.item import Item as ItemResource
 from girder.constants import AccessType
 from girder.exceptions import RestException
 from girder.models.file import File
 from girder.models.item import Item
 from girder.utility.progress import setResponseTimeLimit
-
+from large_image.cache_util import strhash
 from large_image.constants import TileInputUnits
 from large_image.exceptions import TileGeneralException
-from large_image.cache_util import strhash
 
-from ..models.image_item import ImageItem
 from .. import loadmodelcache
-
+from ..models.image_item import ImageItem
 
 MimeTypeExtensions = {
     'image/jpeg': 'jpg',
@@ -88,7 +87,7 @@ def _handleETag(key, item, *args, **kwargs):
     conditions = [str(x) for x in cherrypy.request.headers.elements('If-None-Match') or []]
     if conditions == ['*'] or etag in conditions:
         raise cherrypy.HTTPRedirect([], 304)
-    # Explicitly set a max-age to recheck the cahe after a while
+    # Explicitly set a max-age to recheck the cache after a while
     setResponseHeader('Cache-control', 'max-age=3600')
 
 
@@ -448,7 +447,7 @@ class TilesItemResource(ItemResource):
         .param y: the Y coordinate of the tile (0 is the top).
         :param imageArgs: additional arguments to use when fetching image data.
         :param mayRedirect: if True or one of 'any', 'encoding', or 'exact',
-            allow return a response whcih may be a redirect.
+            allow return a response which may be a redirect.
         :return: a function that returns the raw image data.
         """
         try:
