@@ -1,11 +1,16 @@
 import math
-from unittest import mock
 import os
-import pytest
-import requests
 import shutil
 import struct
 import time
+from unittest import mock
+
+import pytest
+import requests
+from girder_jobs.constants import JobStatus
+from girder_jobs.models.job import Job
+from girder_large_image import constants, getGirderTileSource, loadmodelcache
+from girder_large_image.models.image_item import ImageItem
 
 from girder.constants import SortDir
 from girder.models.file import File
@@ -13,15 +18,7 @@ from girder.models.item import Item
 from girder.models.setting import Setting
 from girder.models.token import Token
 from girder.models.user import User
-
-from girder_jobs.constants import JobStatus
-from girder_jobs.models.job import Job
-
 from large_image import getTileSource
-from girder_large_image import constants
-from girder_large_image import getGirderTileSource
-from girder_large_image import loadmodelcache
-from girder_large_image.models.image_item import ImageItem
 
 from . import girder_utilities as utilities
 
@@ -148,7 +145,7 @@ def _postTileViaHttp(server, admin, itemId, fileId, jobAction=None, data=None, c
         specified, fileId is ignored (pass as part of the data dictionary if
         it is required).
     :returns: metadata from the tile if the conversion was successful,
-              False if it converted but didn't result in useable tiles, and
+              False if it converted but didn't result in usable tiles, and
               None if it failed.
     """
     headers = {
@@ -426,7 +423,7 @@ def testTilesFromPNG(boundServer, admin, fsAssetstore, girderWorker):
     resp = boundServer.request(path='/item/%s/tiles' % itemId, method='DELETE', user=admin)
     assert utilities.respStatus(resp) == 200
     assert resp.json['deleted'] is True
-    # We should no longer have tile informaton
+    # We should no longer have tile information
     resp = boundServer.request(path='/item/%s/tiles' % itemId, user=admin)
     assert utilities.respStatus(resp) == 400
     assert 'No large image file' in resp.json['message']
